about summary refs log tree commit diff stats
diff options
context:
space:
mode:
-rw-r--r--038new_text.cc6
-rw-r--r--058to_text.cc3
2 files changed, 5 insertions, 4 deletions
diff --git a/058to_text.cc b/058to_text.cc
index 924846df..becc3842 100644
--- a/058to_text.cc
+++ b/058to_text.cc
@@ -2,9 +2,6 @@
 //: Later layers will allow us to override this to do something smarter for
 //: specific types.
 
-:(before "End Mu Types Initialization")
-put(Type_abbreviations, "text", new_type_tree("address:array:character"));
-
 :(before "End Primitive Recipe Declarations")
 TO_TEXT,
 :(before "End Primitive Recipe Numbers")
diff --git a/038new_text.cc b/038new_text.cc
index 043e0498..9ecc992c 100644
--- a/038new_text.cc
+++ b/038new_text.cc
@@ -1,4 +1,8 @@
-//: Extend 'new' to handle a unicode string literal argument.
+//: Extend 'new' to handle a unicode string literal argument or 'text'.
+
+//: A Mu text is an address to an array of characters.
+:(before "End Mu Types Initialization")
+put(Type_abbreviations, "text", new_type_tree("address:array:character"));
 
 :(scenario new_string)
 def main [